@@ -55,8 +55,8 @@
 #endif /* GDK_WINDOWING_X11 */
 
 
-#define GIMV_MPLAYER_REFRESH_RATE 300 /* 0.3 [sec] */
-#define GIMV_MPLAYER_BUF_SIZE 2048
+#define GIMV_MPLAYER_REFRESH_RATE 100 /* 0.1 [sec] */
+#define GIMV_MPLAYER_BUF_SIZE 1024
 
 #ifdef USE_GTK2
 #  define gtk_object_class_add_signals(class, func, type)
@@ -326,6 +326,8 @@ gimv_mplayer_class_init (GimvMPlayerClass *class)
    class->play                 = NULL;
    class->stop                 = NULL;
    class->pause                = NULL;
+   class->position_changed     = NULL;
+   class->identified           = NULL;
 }
 
 
@@ -517,6 +519,24 @@ gimv_mplayer_send_configure (GimvMPlayer *player)
 }
 
 
+/* To fit image to frame when use XVideo driver */
+static void
+gimv_mplayer_send_dummy_configure (GimvMPlayer *player)
+{
+   GtkWidget *widget;
+   gint width, height;
+
+   g_return_if_fail (GTK_IS_WIDGET (player));
+
+   widget = GTK_WIDGET (player);
+   width  = widget->allocation.width;
+   height = widget->allocation.height;
+
+   gdk_window_resize (widget->window, width - 1, height - 1);
+   gdk_window_resize (widget->window, width, height);
+}
+
+
 
 /******************************************************************************
  *
@@ -669,7 +689,9 @@ gimv_mplayer_start (GimvMPlayer *player, gfloat pos, gfloat speed)
       }
 #endif /* GDK_WINDOWING_X11 */
 
-      if (player->flags & GimvMPlayerEmbedFlag) {
+      if (player->vo && !strcmp ("x11", player->vo) &&
+          player->flags & GimvMPlayerEmbedFlag)
+      {
          g_snprintf (buf, buf_size, "scale=%d:%d",
                      GTK_WIDGET (player)->allocation.width,
                      GTK_WIDGET (player)->allocation.height);
@@ -741,6 +763,9 @@ gimv_mplayer_stop (GimvMPlayer *player)
    context = gimv_mplayer_get_player_child (player);
    if (!context) return;
 
+   if (player->status == GimvMPlayerStatusPause)
+      gimv_mplayer_toggle_pause (player);
+
    gimv_mplayer_send_command (player, "quit\n");
 
    waitpid (context->pid, NULL, WUNTRACED);
@@ -856,6 +881,10 @@ gimv_mplayer_set_file (GimvMPlayer *player,
       struct stat st;
 
       args = g_list_append (args, g_strdup (player->command));
+      args = g_list_append (args, g_strdup ("-vo"));
+      args = g_list_append (args, g_strdup ("null"));
+      args = g_list_append (args, g_strdup ("-ao"));
+      args = g_list_append (args, g_strdup ("null"));
       args = g_list_append (args, g_strdup ("-identify"));
       args = g_list_append (args, g_strdup (file));
       if (player->include_file && *player->include_file
@@ -867,7 +896,11 @@ gimv_mplayer_set_file (GimvMPlayer *player,
 
       start_command (player, args, NULL, FALSE,
                      process_line_identify, &identify_supported, identify_done);
-      /* gtk_main (); */
+#if 0
+      gtk_grab_add (GTK_WIDGET (player));
+      gtk_main ();
+      gtk_grab_remove (GTK_WIDGET (player));
+#endif
 
       if (player->media_info.video || player->media_info.audio
           || !identify_supported)
@@ -1307,6 +1340,11 @@ start_command (GimvMPlayer *player,
 
    pid = fork ();
 
+   if (pid < 0) {
+      g_warning ("GimvMPlayer: faild to fork(2): %s", strerror (errno));
+      return NULL;
+   }
+
    if (pid > 0) {
       /* parent process */
       context = g_new0 (ChildContext, 1);
@@ -1371,7 +1409,19 @@ start_command (GimvMPlayer *player,
 
       /* exec */
       putenv ("LC_ALL=C");
+
       execvp (argv[0], argv);
+
+      close (out_fd[1]);
+      close (err_fd[1]);
+      close (in_fd[0]);
+
+      if (errno) {
+         g_warning ("GimvMPlayer: cannot execute command: %s", strerror (errno));
+      } else {
+         g_warning ("GimvMPlayer: cannot execute command: Unknown error");
+      }
+
       _exit (255);
    }
 
@@ -1417,29 +1467,13 @@ timeout_check_child (gpointer data)
 }
 
 
-#define LINE_END(end, str) \
-{ \
-   gchar *end1, *end2; \
-   if (!str || !*str) { \
-      end = NULL; \
-   } else { \
-      end1 = strchr (str, '\n'); \
-      end2 = strchr (str, '\r'); \
-      if (end1 && end2) \
-         end = (end2 < end1) ? end2 : end1; \
-      else \
-         end = end1 ? end1 : end2; \
-   } \
-}
-
-
 static void
 process_lines (ChildContext *context,
-               gchar buf[GIMV_MPLAYER_BUF_SIZE * 2], gint size,
+               gchar buf[GIMV_MPLAYER_BUF_SIZE * 2], gint bufsize,
                gchar stock_buf[GIMV_MPLAYER_BUF_SIZE], gint *remain_size,
                gboolean is_stderr)
 {
-   gint len;
+   gint i, len, size;
    gchar *src, *end;
 
    g_return_if_fail (buf && stock_buf);
@@ -1447,24 +1481,28 @@ process_lines (ChildContext *context,
    g_return_if_fail (remain_size);
 
    src = buf;
+   size = bufsize;
 
-   LINE_END (end, src);
+   while (src && size >= 0) {
+      end = NULL;
+
+      for (i = 0; i < size; i++) {
+         if (src[i] == '\n' || src[i] == '\r') {
+            end = src + i;
+            break;
+         }
+      }
+
+      if (!end) break;
 
-   while (end && src) {
       *end = '\0';
-
       len = end - src;
 
       if (context->process_line_fn)
          context->process_line_fn (context, src, len, is_stderr);
 
+      size -= len;
       src = end + 1;
-      size -= (end - src);
-      if (src) {
-         LINE_END (end, src);
-      } else {
-         end = NULL;
-      }
    }
 
    if (size <= 0 || size > GIMV_MPLAYER_BUF_SIZE - 1 || !src || !*src) {
@@ -1496,8 +1534,17 @@ process_output (ChildContext *context)
    }
 
    n = read (context->stderr_fd, buf, GIMV_MPLAYER_BUF_SIZE - 1);
-   if (n == 0) {
-   } else if (n > 0) {
+
+   switch (errno) {
+   case 0:
+   case EAGAIN:
+      break;
+   default:
+      g_warning ("GimvMPlayer: stderr: %s", strerror (errno));
+      break;
+   }
+
+   if (n >= 0) {
       next[MIN (GIMV_MPLAYER_BUF_SIZE - 1, n)] = '\0';
       size += MIN (GIMV_MPLAYER_BUF_SIZE - 1, n);
 
@@ -1517,24 +1564,40 @@ process_output (ChildContext *context)
    }
 
    n = read (context->stdout_fd, next, GIMV_MPLAYER_BUF_SIZE - 1);
-   if (n == 0) {
+
+   switch (errno) {
+   case 0:
+   case EAGAIN:
+      if (n < 0)
+         return TRUE;
+      break;
+   default:
+      g_warning ("GimvMPlayer: stdout: %s", strerror (errno));
+      break;
+   }
+
+   if (n < 0) return TRUE;
+
+   if (n >= 0) {
+      gint len = MIN (GIMV_MPLAYER_BUF_SIZE - 1, n);
+
+      next[len] = '\0';
+      size += len;
+      pos = context->player->pos;
+
+      process_lines (context, buf, size,
+                     context->stdout_buf, &context->stdout_size,
+                     FALSE);
+
+      if (fabs (context->player->pos - pos) > 0.1)
+         gtk_signal_emit (GTK_OBJECT (context->player),
+                          gimv_mplayer_signals[POS_CHANGED_SIGNAL]);
+   }
+
+   if (n == 0)
       return FALSE;
-   } else if (n < 0)
+   else
       return TRUE;
-
-   next[MIN (GIMV_MPLAYER_BUF_SIZE - 1, n)] = '\0';
-   size += MIN (GIMV_MPLAYER_BUF_SIZE - 1, n);
-   pos = context->player->pos;
-
-   process_lines (context, buf, size,
-                  context->stdout_buf, &context->stdout_size,
-                  FALSE);
-
-   if (fabs (context->player->pos - pos) > 0.1)
-      gtk_signal_emit (GTK_OBJECT (context->player),
-                       gimv_mplayer_signals[POS_CHANGED_SIGNAL]);
-
-   return TRUE;
 }
 
 
@@ -1613,6 +1676,9 @@ process_line (ChildContext *context,
          /* set status */
          if (player->status != GimvMPlayerStatusPlay) {
             player->status = GimvMPlayerStatusPlay;
+            if (GTK_WIDGET_MAPPED (player)) {
+               gimv_mplayer_send_dummy_configure (player);
+            }
             gtk_signal_emit (GTK_OBJECT (player),
                              gimv_mplayer_signals[PLAY_SIGNAL]);
          }
