@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: listview.c,v 1.1.2.5 2003/05/13 11:25:56 makeinu Exp $
+ * $Id: listview.c,v 1.3 2003/06/18 09:26:54 makeinu Exp $
  */
 
 #include <string.h>
@@ -27,12 +27,12 @@
 
 #include "dnd.h"
 #include "fileutil.h"
-#include "icon_widget.h"
+#include "gimv_thumb.h"
+#include "thumbnail_view.h"
+#include "gimv_image_info.h"
 #include "gimv_plugin.h"
 #include "gtk2-compat.h"
-#include "image_info.h"
-#include "thumbnail.h"
-#include "thumbnail_view.h"
+#include "icon_widget.h"
 #include "listview.h"
 #include "listview_prefs.h"
 
@@ -86,7 +86,7 @@ GimvPluginInfo gimv_plugin_info =
 {
    if_version:    GIMV_PLUGIN_IF_VERSION,
    name:          N_("Thumbnail View List Mode"),
-   version:       "0.0.1",
+   version:       "0.0.2",
    author:        N_("Takuro Ashie"),
    description:   NULL,
    get_implement: gimv_plugin_get_impl,
@@ -104,18 +104,18 @@ typedef struct ThumbViewData_Tag
    gint       colnum;
    gchar     *dest_mode;
 
-   Thumbnail *focused;
+   GimvThumb *focused;
 } ThumbViewData;
 
 
-typedef struct ThumbnailData_Tag
+typedef struct GimvThumbData_Tag
 {
    GtkWidget *widget;
-} ThumbnailData;
+} GimvThumbData;
 
 
 /* for converting thumbnail data to string */
-typedef gchar *(*ListViewDataStr) (Thumbnail *thumb);
+typedef gchar *(*ListViewDataStr) (GimvThumb *thumb);
 
 typedef struct _ListViewDisplayData
 {
@@ -124,19 +124,19 @@ typedef struct _ListViewDisplayData
 } ListViewDisplayData;
 
 
-static gchar *label_filename   (Thumbnail *thumb);
-static gchar *label_size       (Thumbnail *thumb);
-static gchar *label_mtime      (Thumbnail *thumb);
-static gchar *label_image_type (Thumbnail *thumb);
+static gchar *label_filename   (GimvThumb *thumb);
+static gchar *label_size       (GimvThumb *thumb);
+static gchar *label_mtime      (GimvThumb *thumb);
+static gchar *label_image_type (GimvThumb *thumb);
 
 static ThumbViewData *listview_new                    (ThumbView *tv);
 static void           calc_col_row_num                (ThumbView *tv,
                                                        gchar     *mode,
                                                        gint      *colnum,
                                                        gint      *rownum);
-gchar                *listview_create_label_str       (Thumbnail *thumb);
+gchar                *listview_create_label_str       (GimvThumb *thumb);
 static gboolean       listview_append_thumb_frame     (ThumbView *tv,
-                                                       Thumbnail *thumb,
+                                                       GimvThumb *thumb,
                                                        gchar     *dest_mode);
 void                  listview_create_title_idx_list  ();
 
@@ -169,7 +169,7 @@ static gboolean listview_dragging = FALSE;
 static gboolean
 cb_icon_key_press (GtkWidget *widget,
                    GdkEventKey *event,
-                   Thumbnail *thumb)
+                   GimvThumb *thumb)
 {
    ThumbView *tv;
 
@@ -177,7 +177,7 @@ cb_icon_key_press (GtkWidget *widget,
 
    if (!thumb) return FALSE;
 
-   tv = thumbnail_get_parent_thumbview (thumb);
+   tv = gimv_thumb_get_parent_thumbview (thumb);
    g_return_val_if_fail (tv, FALSE);
 
    if (thumbview_thumb_key_press_cb(widget, event, thumb))
@@ -241,7 +241,7 @@ cb_icon_key_press (GtkWidget *widget,
 static gboolean
 cb_icon_button_press (GtkWidget *icon, GdkEventButton *event, gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
    ThumbView *tv;
    gboolean clear = TRUE, found = FALSE;
 
@@ -283,7 +283,7 @@ cb_icon_button_press (GtkWidget *icon, GdkEventButton *event, gpointer data)
 static gboolean
 cb_icon_button_release (GtkWidget *icon, GdkEventButton *event, gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
    ThumbView *tv;
 
    g_return_val_if_fail (icon && thumb, TRUE);
@@ -314,7 +314,7 @@ cb_icon_button_release (GtkWidget *icon, GdkEventButton *event, gpointer data)
 static gboolean
 cb_icon_motion_notify (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
-   Thumbnail *thumb = data;
+   GimvThumb *thumb = data;
 
    listview_dragging = TRUE;
 
@@ -325,11 +325,11 @@ cb_icon_motion_notify (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 
 
 static gboolean
-cb_icon_focus_in (GtkWidget *icon, GdkEventFocus *event, Thumbnail *thumb)
+cb_icon_focus_in (GtkWidget *icon, GdkEventFocus *event, GimvThumb *thumb)
 {
    ThumbView *tv;
    ThumbViewData *tv_data;
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
 
    g_return_val_if_fail (thumb, FALSE);
 
@@ -365,7 +365,7 @@ cb_expose (GtkWidget *widget, GdkEventExpose *event, ThumbView *tv)
  *
  ******************************************************************************/
 static gchar *
-label_filename (Thumbnail *thumb)
+label_filename (GimvThumb *thumb)
 {
    const gchar *filename;
    gchar *tmpstr;
@@ -374,7 +374,7 @@ label_filename (Thumbnail *thumb)
 
    g_return_val_if_fail (thumb, NULL);
 
-   filename = g_basename(image_info_get_path (thumb->info));
+   filename = g_basename(gimv_image_info_get_path (thumb->info));
 
    tmpstr = gimv_filename_to_internal (filename);
 
@@ -391,7 +391,7 @@ label_filename (Thumbnail *thumb)
 
 
 static gchar *
-label_size (Thumbnail *thumb)
+label_size (GimvThumb *thumb)
 {
    gchar *size_str, buf[BUF_SIZE];
    gboolean show_title;
@@ -411,7 +411,7 @@ label_size (Thumbnail *thumb)
 
 
 static gchar *
-label_mtime (Thumbnail *thumb)
+label_mtime (GimvThumb *thumb)
 {
    gchar *time_str, *str;
    gboolean show_title;
@@ -431,7 +431,7 @@ label_mtime (Thumbnail *thumb)
 
 
 static gchar *
-label_image_type (Thumbnail *thumb)
+label_image_type (GimvThumb *thumb)
 {
    gchar buf[BUF_SIZE];
    const gchar *filename;
@@ -439,7 +439,7 @@ label_image_type (Thumbnail *thumb)
 
    g_return_val_if_fail (thumb, NULL);
 
-   filename = image_info_get_path (thumb->info);
+   filename = gimv_image_info_get_path (thumb->info);
    listview_prefs_get_value("show_title", (gpointer *) &show_title);
    if (show_title)
       g_snprintf (buf, BUF_SIZE, _("Type: %s"),
@@ -506,7 +506,7 @@ calc_col_row_num (ThumbView *tv, gchar *mode, gint *colnum, gint *rownum)
 
 
 static gboolean
-calc_thumbframe_pos (Thumbnail *thumb, gint *col, gint *row)
+calc_thumbframe_pos (GimvThumb *thumb, gint *col, gint *row)
 {
    ThumbView *tv;
    ThumbViewData *tv_data;
@@ -536,7 +536,7 @@ calc_thumbframe_pos (Thumbnail *thumb, gint *col, gint *row)
 
 
 gchar *
-listview_create_label_str (Thumbnail *thumb)
+listview_create_label_str (GimvThumb *thumb)
 {
    GList *node;
    gchar *label;
@@ -568,10 +568,10 @@ listview_create_label_str (Thumbnail *thumb)
 
 
 static gboolean
-listview_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode)
+listview_append_thumb_frame (ThumbView *tv, GimvThumb *thumb, gchar *dest_mode)
 {
    ThumbViewData *tv_data;
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
    GdkPixmap *thumbnail = NULL, *icon = NULL;
    GdkBitmap *thumbnail_mask = NULL, *icon_mask = NULL;
    GtkWidget *widget = NULL;
@@ -586,7 +586,7 @@ listview_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode)
 
    thumb_data = g_hash_table_lookup (thumb->mode_data, LIST_VIEW_LABEL);
    if (!thumb_data) {
-      thumb_data = g_new0 (ThumbnailData, 1);
+      thumb_data = g_new0 (GimvThumbData, 1);
       g_hash_table_insert (thumb->mode_data, LIST_VIEW_LABEL, thumb_data);
    }
 
@@ -595,7 +595,7 @@ listview_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode)
       frame_size = tv->ThumbnailSize;
       icon_label = listview_create_label_str (thumb);
    } else {
-      const gchar *filename = g_basename(image_info_get_path (thumb->info));
+      const gchar *filename = g_basename(gimv_image_info_get_path (thumb->info));
       icon_label = gimv_filename_to_internal (filename);
       frame_size = ICON_SIZE;
    }
@@ -605,8 +605,8 @@ listview_append_thumb_frame (ThumbView *tv, Thumbnail *thumb, gchar *dest_mode)
                                          frame_size, frame_size);
    g_free (icon_label);
 
-   thumbnail_get_icon  (thumb, &icon, &icon_mask);
-   thumbnail_get_thumb (thumb, &thumbnail, &thumbnail_mask);
+   gimv_thumb_get_icon  (thumb, &icon, &icon_mask);
+   gimv_thumb_get_thumb (thumb, &thumbnail, &thumbnail_mask);
 
    if (!strcmp (label, LIST_VIEW_LABEL)) {
       if (icon) {
@@ -699,12 +699,12 @@ listview_remove_thumbview_data (ThumbView *tv)
 /*
  *  listview_remove_thumbnail_data:
  *
- *  thumb : Pointer to the Thumbnail struct.
+ *  thumb : Pointer to the GimvThumb struct.
  */
 void
-listview_remove_thumbnail_data (Thumbnail *thumb)
+listview_remove_thumbnail_data (GimvThumb *thumb)
 {
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
 
    if (!thumb) return;
 
@@ -719,7 +719,7 @@ listview_remove_thumbnail_data (Thumbnail *thumb)
 GList *
 list_view_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 {
-   Thumbnail  *thumb;
+   GimvThumb  *thumb;
    GList *node, *loadlist = NULL;
    gboolean thumb_loaded;
 
@@ -727,7 +727,7 @@ list_view_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 
    node = start;
    while (node) {
-      thumb = (Thumbnail *) node->data;
+      thumb = (GimvThumb *) node->data;
 
       thumb_loaded = listview_append_thumb_frame (tv, thumb, dest_mode);
       if (!thumb_loaded)
@@ -741,10 +741,10 @@ list_view_append_thumb_frames (ThumbView *tv, GList *start, gchar *dest_mode)
 
 
 GtkWidget *
-listview_add_thumbnail (Thumbnail *thumb, gchar *dest_mode,
+listview_add_thumbnail (GimvThumb *thumb, gchar *dest_mode,
                         ThumbLoadType type)
 {
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
    GdkPixmap *icon = NULL, *thumbnail = NULL;
    GdkBitmap *icon_mask = NULL, *thumbnail_mask = NULL;
    gchar *label;
@@ -756,8 +756,8 @@ listview_add_thumbnail (Thumbnail *thumb, gchar *dest_mode,
 
    label = dest_mode;
 
-   thumbnail_get_icon (thumb, &icon, &icon_mask);
-   thumbnail_get_thumb (thumb, &thumbnail, &thumbnail_mask);
+   gimv_thumb_get_icon (thumb, &icon, &icon_mask);
+   gimv_thumb_get_thumb (thumb, &thumbnail, &thumbnail_mask);
 
    if (!strcmp (label, LIST_VIEW_LABEL) && icon) {
       icon_widget_set_pixmap (ICON_WIDGET (thumb_data->widget),
@@ -811,11 +811,11 @@ listview_redraw (ThumbView *tv, gchar *dest_mode,
    *loadlist = NULL;
    node = tv->thumblist;
    while (node) {
-      Thumbnail *thumb = node->data;
+      GimvThumb *thumb = node->data;
       GdkPixmap *pixmap = NULL;
       GdkBitmap *mask = NULL;
 
-      thumbnail_get_thumb (thumb, &pixmap, &mask);
+      gimv_thumb_get_thumb (thumb, &pixmap, &mask);
       if (!pixmap)
          *loadlist = g_list_append (*loadlist, thumb);
       node = g_list_next (node);
@@ -827,11 +827,11 @@ listview_redraw (ThumbView *tv, gchar *dest_mode,
  *  listview_refresh_thumbnail:
  *     @ Create thumbnail from original image and draw it.
  *
- *  thumb  : Pointer to the Thumbnail struct.
+ *  thumb  : Pointer to the GimvThumb struct.
  *  Return : TRUE if success.
  */
 gboolean
-listview_refresh_thumbnail (Thumbnail *thumb, ThumbLoadType type)
+listview_refresh_thumbnail (GimvThumb *thumb, ThumbLoadType type)
 {
    GtkWidget *widget;
    ThumbView *tv;
@@ -889,10 +889,10 @@ listview_resize (ThumbView *tv)
 
 
 void
-listview_adjust (ThumbView *tv, Thumbnail *thumb)
+listview_adjust (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
-   ThumbnailData *thumb_data;   
+   GimvThumbData *thumb_data;   
    GList *node;
    GtkWidget *icon;
    GtkScrolledWindow *scrollwin;
@@ -946,9 +946,9 @@ listview_adjust (ThumbView *tv, Thumbnail *thumb)
 
 
 gboolean
-listview_set_selection (Thumbnail *thumb, gboolean select)
+listview_set_selection (GimvThumb *thumb, gboolean select)
 {
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
 
    g_return_val_if_fail (thumb, FALSE);
 
@@ -967,10 +967,10 @@ listview_set_selection (Thumbnail *thumb, gboolean select)
 
 
 void
-listview_set_focus (ThumbView *tv, Thumbnail *thumb)
+listview_set_focus (ThumbView *tv, GimvThumb *thumb)
 {
    ThumbViewData *tv_data;
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
 
    g_return_if_fail (tv);
 
@@ -988,7 +988,7 @@ listview_set_focus (ThumbView *tv, Thumbnail *thumb)
 }
 
 
-Thumbnail *
+GimvThumb *
 listview_get_focus (ThumbView *tv)
 {
    ThumbViewData *tv_data;
@@ -1003,9 +1003,9 @@ listview_get_focus (ThumbView *tv)
 
 
 gboolean
-listview_thumbnail_is_in_viewport (ThumbView *tv, Thumbnail *thumb)
+listview_thumbnail_is_in_viewport (ThumbView *tv, GimvThumb *thumb)
 {
-   ThumbnailData *thumb_data;
+   GimvThumbData *thumb_data;
    GdkRectangle area, cell_area, intersect_area;
    GtkAdjustment *hadj;
 
