@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gimv_image_win.c,v 1.1.2.4 2003/06/11 09:40:12 makeinu Exp $
+ * $Id: gimv_image_win.c,v 1.7 2003/07/06 16:46:21 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -27,22 +27,27 @@
 #include "gimageview.h"
 
 #include "charset.h"
-#include "comment_view.h"
 #include "cursors.h"
-#include "gimv_icon_stock.h"
-#include "gimv_prefs_win.h"
 #include "gtk2-compat.h"
 #include "gtkutils.h"
-#include "help.h"
+#include "gimv_comment_view.h"
+#include "gimv_icon_stock.h"
 #include "gimv_image_view.h"
 #include "gimv_image_win.h"
+#include "gimv_prefs_win.h"
+#include "gimv_thumb_win.h"
+#include "help.h"
 #include "menu.h"
 #include "prefs.h"
-#include "slideshow.h"
-#include "thumbnail_window.h"
 
 #define IMGWIN_FULLSCREEN_HIDE_CURSOR_DELAY 1000
 
+enum {
+   SHOW_FULLSCREEN_SIGNAL,
+   HIDE_FULLSCREEN_SIGNAL,
+   LAST_SIGNAL
+};
+
 enum {
    IMG_FIRST,
    IMG_PREV,
@@ -80,6 +85,8 @@ struct GimvImageWinPriv_Tag
    gint             win_width;
    gint             win_height;
 
+   GdkColor        *fs_bg_color;
+
    guint            hide_cursor_timer_id;
 
    guint            slideshow_interval;  /* [msec] */
@@ -87,27 +94,25 @@ struct GimvImageWinPriv_Tag
 };
 
 
-static GList *ImageWinList = NULL;
-static GimvImageWin *shared_img_win;
+static void     gimv_image_win_class_init           (GimvImageWinClass *klass);
+static void     gimv_image_win_init                 (GimvImageWin *iw);
+static void     gimv_image_win_destroy              (GtkObject *object);
+static void     gimv_image_win_realize              (GtkWidget *widget);
+static void     gimv_image_win_real_show_fullscreen (GimvImageWin *iw);
+static void     gimv_image_win_real_hide_fullscreen (GimvImageWin *iw);
 
+static void       create_imageview_menus            (GimvImageWin  *iw);
+static GtkWidget *create_toolbar                    (GimvImageWin  *iw,
+                                                     GtkWidget     *container);
+static GtkWidget *create_player_toolbar             (GimvImageWin  *iw,
+                                                     GtkWidget     *container);
 
-static void     gimv_image_win_class_init (GimvImageWinClass *klass);
-static void     gimv_image_win_init       (GimvImageWin *iw);
-static void     gimv_image_win_destroy    (GtkObject *object);
-static void     gimv_image_win_realize    (GtkWidget *widget);
+static void     gimv_image_win_set_win_size         (GimvImageWin  *iw);
+static void     gimv_image_win_set_window_title     (GimvImageWin  *iw);
+static void     gimv_image_win_set_statusbar_info   (GimvImageWin  *iw);
 
-static void       create_imageview_menus  (GimvImageWin  *iw);
-static GtkWidget *create_toolbar          (GimvImageWin  *iw,
-                                           GtkWidget     *container);
-static GtkWidget *create_player_toolbar   (GimvImageWin  *iw,
-                                           GtkWidget     *container);
-
-static void     gimv_image_win_set_win_size       (GimvImageWin  *iw);
-static void     gimv_image_win_set_window_title   (GimvImageWin  *iw);
-static void     gimv_image_win_set_statusbar_info (GimvImageWin  *iw);
-
-static void     gimv_image_win_fullscreen_show    (GimvImageWin *iw);
-static void     gimv_image_win_fullscreen_hide    (GimvImageWin *iw);
+static void     gimv_image_win_fullscreen_show      (GimvImageWin *iw);
+static void     gimv_image_win_fullscreen_hide      (GimvImageWin *iw);
 
 /* callback functions for menubar */
 static void     cb_file_select          (gpointer      data,
@@ -223,10 +228,10 @@ static gboolean cb_seekbar_released (GtkWidget      *widget,
 static void     cb_image_changed       (GimvImageView *iv,
                                         GimvImageWin *iw);
 static void     cb_load_start          (GimvImageView *iv,
-                                        ImageInfo *info,
+                                        GimvImageInfo *info,
                                         GimvImageWin *iw);
 static void     cb_load_end            (GimvImageView *iv,
-                                        ImageInfo *info,
+                                        GimvImageInfo *info,
                                         gboolean cancel,
                                         GimvImageWin *iw);
 static void     cb_set_list            (GimvImageView  *iv,
@@ -320,6 +325,11 @@ GtkItemFactoryEntry gimv_image_win_move_items [] =
 
 
 static GtkWindowClass *parent_class = NULL;
+static gint            gimv_image_win_signals[LAST_SIGNAL] = {0};
+
+
+static GList         *ImageWinList   = NULL;
+static GimvImageWin  *shared_img_win = NULL;
 
 
 guint
@@ -339,7 +349,7 @@ gimv_image_win_get_type (void)
          (GtkClassInitFunc) NULL,
       };
 
-      gimv_image_win_type = gtk_type_unique (gtk_window_get_type (),
+      gimv_image_win_type = gtk_type_unique (GTK_TYPE_WINDOW,
                                              &gimv_image_win_info);
    }
 
@@ -355,11 +365,29 @@ gimv_image_win_class_init (GimvImageWinClass *klass)
 
    object_class = (GtkObjectClass *) klass;
    widget_class = (GtkWidgetClass *) klass;
-   parent_class = gtk_type_class (gtk_window_get_type ());
+   parent_class = gtk_type_class (GTK_TYPE_WINDOW);
 
-   object_class->destroy = gimv_image_win_destroy;
+   gimv_image_win_signals[SHOW_FULLSCREEN_SIGNAL]
+      = gtk_signal_new ("show_fullscreen",
+                        GTK_RUN_FIRST,
+                        GTK_CLASS_TYPE(object_class),
+                        GTK_SIGNAL_OFFSET (GimvImageWinClass, show_fullscreen),
+                        gtk_signal_default_marshaller,
+                        GTK_TYPE_NONE, 0);
+   gimv_image_win_signals[HIDE_FULLSCREEN_SIGNAL]
+      = gtk_signal_new ("hide_fullscreen",
+                        GTK_RUN_FIRST,
+                        GTK_CLASS_TYPE(object_class),
+                        GTK_SIGNAL_OFFSET (GimvImageWinClass, hide_fullscreen),
+                        gtk_signal_default_marshaller,
+                        GTK_TYPE_NONE, 0);
 
-   widget_class->realize = gimv_image_win_realize;
+   object_class->destroy  = gimv_image_win_destroy;
+
+   widget_class->realize  = gimv_image_win_realize;
+
+   klass->show_fullscreen = gimv_image_win_real_show_fullscreen;
+   klass->hide_fullscreen = gimv_image_win_real_hide_fullscreen;;
 }
 
 
@@ -394,7 +422,6 @@ gimv_image_win_init (GimvImageWin *iw)
 
    iw->fullscreen                 = NULL;
    iw->priv->hide_cursor_timer_id = 0;
-   iw->slideshow                  = NULL;
    iw->priv->slideshow_interval   = conf.slideshow_interval * 1000;
    iw->priv->slideshow_timer_id   = 0;
    if (conf.slideshow_repeat)
@@ -408,6 +435,15 @@ gimv_image_win_init (GimvImageWin *iw)
                                     conf.imgwin_bg_color[2]);
    }
 
+   if (conf.imgwin_fullscreen_set_bg) {
+      iw->priv->fs_bg_color = g_new0 (GdkColor, 1);
+      iw->priv->fs_bg_color->red   = conf.imgwin_fullscreen_bg_color[0];
+      iw->priv->fs_bg_color->green = conf.imgwin_fullscreen_bg_color[1];
+      iw->priv->fs_bg_color->blue  = conf.imgwin_fullscreen_bg_color[2];
+   } else {
+      iw->priv->fs_bg_color = NULL;
+   }
+
    /* set window properties */
    gtk_window_set_wmclass(GTK_WINDOW(iw), "imagewin", "GImageView");
    gtk_window_set_policy(GTK_WINDOW(iw), TRUE, TRUE, FALSE);
@@ -561,9 +597,9 @@ gimv_image_win_init (GimvImageWin *iw)
 
 
 GtkWidget *
-gimv_image_win_new (ImageInfo *info)
+gimv_image_win_new (GimvImageInfo *info)
 {
-   GimvImageWin *iw = gtk_type_new (gimv_image_win_get_type ());
+   GimvImageWin *iw = gtk_type_new (GIMV_TYPE_IMAGE_WIN);
 
    gimv_image_view_change_image (iw->iv, info);
 
@@ -583,6 +619,9 @@ gimv_image_win_destroy (GtkObject *object)
       if (g_list_length (ImageWinList) == 1 && conf.imgwin_save_win_state)
          gimv_image_win_save_state (iw);
 
+      g_free (iw->priv->fs_bg_color);
+      iw->priv->fs_bg_color = NULL;
+
       g_free (iw->priv);
       iw->priv = NULL;
    }
@@ -605,7 +644,7 @@ gimv_image_win_destroy (GtkObject *object)
       GTK_OBJECT_CLASS (parent_class)->destroy (object);
 
    /* quit when last window */
-   if (!gimv_image_win_get_list() && !thumbwin_get_list()) {
+   if (!gimv_image_win_get_list() && !gimv_thumb_win_get_list()) {
       gimv_quit();
    }
 }
@@ -836,7 +875,8 @@ create_toolbar (GimvImageWin *iw, GtkWidget *container)
 
    /* x scale spinner */
    adj = (GtkAdjustment *) gtk_adjustment_new (x_scale,
-                                               MIN_THUMB_SIZE, MAX_THUMB_SIZE,
+                                               GIMV_THUMB_WIN_MIN_THUMB_SIZE,
+                                               GIMV_THUMB_WIN_MAX_THUMB_SIZE,
                                                1.0, 5.0, 0.0);
    spinner = gtkutil_create_spin_button (adj);
    gtk_widget_set_name (spinner, "XScaleSpinner");
@@ -850,7 +890,8 @@ create_toolbar (GimvImageWin *iw, GtkWidget *container)
 
    /* y scale spinner */
    adj = (GtkAdjustment *) gtk_adjustment_new (y_scale,
-                                               MIN_THUMB_SIZE, MAX_THUMB_SIZE,
+                                               GIMV_THUMB_WIN_MIN_THUMB_SIZE,
+                                               GIMV_THUMB_WIN_MAX_THUMB_SIZE,
                                                1.0, 5.0, 0.0);
    spinner = gtkutil_create_spin_button (adj);
    gtk_widget_set_name (spinner, "YScaleSpinner");
@@ -1057,7 +1098,7 @@ gimv_image_win_set_window_title (GimvImageWin *iw)
    g_return_if_fail (iw->iv);
    if (!g_list_find (gimv_image_view_get_list(), iw->iv)) return;
 
-   if (iw->iv->info && image_info_get_path (iw->iv->info)) {
+   if (iw->iv->info && gimv_image_info_get_path (iw->iv->info)) {
       filename = g_basename (iw->iv->info->filename);
       dirname = g_dirname (iw->iv->info->filename);
    } else {
@@ -1114,9 +1155,9 @@ gimv_image_win_set_statusbar_info (GimvImageWin *iw)
    if (!g_list_find (gimv_image_view_get_list(), iw->iv)) return;
 
    if (iw->iv->info) {
-      filename = image_info_get_path (iw->iv->info);
-      format = image_info_get_format (iw->iv->info);
-      image_info_get_image_size (iw->iv->info, &width, &height);
+      filename = gimv_image_info_get_path (iw->iv->info);
+      format = gimv_image_info_get_format (iw->iv->info);
+      gimv_image_info_get_image_size (iw->iv->info, &width, &height);
    }
 
    tmpstr = charset_to_internal (filename, conf.charset_filename,
@@ -1171,7 +1212,7 @@ cb_open_imagewin (gpointer data, guint action, GtkWidget *widget)
 static void
 cb_open_thumbwin (gpointer data, guint action, GtkWidget *widget)
 {
-   thumbwin_open_window();
+   gimv_thumb_win_open_window();
 }
 
 
@@ -1353,7 +1394,7 @@ cb_edit_comment (GimvImageWin *iw, guint action, GtkWidget *menuitem)
    g_return_if_fail (iw->iv);
 
    if (iw->iv->info)
-      comment_view_create_window (iw->iv->info);
+      gimv_comment_view_create_window (iw->iv->info);
 }
 
 
@@ -1705,7 +1746,7 @@ cb_image_changed (GimvImageView *iv, GimvImageWin *iw)
 
 
 static void
-cb_load_start (GimvImageView *iv, ImageInfo *info, GimvImageWin *iw)
+cb_load_start (GimvImageView *iv, GimvImageInfo *info, GimvImageWin *iw)
 {
    g_return_if_fail (iw);
 
@@ -1715,7 +1756,7 @@ cb_load_start (GimvImageView *iv, ImageInfo *info, GimvImageWin *iw)
 
 static void
 cb_load_end (GimvImageView *iv,
-             ImageInfo *info,
+             GimvImageInfo *info,
              gboolean cancel,
              GimvImageWin *iw)
 {
@@ -1857,9 +1898,7 @@ cb_draw_area_key_press (GtkWidget *widget,
         
    switch (event->keyval) {
    case GDK_Escape:
-      if (iw->slideshow) {
-         gtk_widget_destroy (GTK_WIDGET (iw));
-      } else if (iw->priv->flags & GimvImageWinMaximizeFlag) {
+      if (iw->priv->flags & GimvImageWinMaximizeFlag) {
          menu_check_item_set_active (iw->view_menu, "/Maximize",
                                      !(iw->priv->flags & GimvImageWinMaximizeFlag));
       }
@@ -2088,8 +2127,32 @@ set_menu_sensitive (GimvImageWin *iw, gboolean sensitive)
 }
 
 
-static void
+void
 gimv_image_win_fullscreen_show (GimvImageWin *iw)
+{
+   g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
+
+   if (iw->fullscreen) return;
+
+   gtk_signal_emit (GTK_OBJECT(iw),
+                    gimv_image_win_signals[SHOW_FULLSCREEN_SIGNAL]);
+}
+
+
+void
+gimv_image_win_fullscreen_hide (GimvImageWin *iw)
+{
+   g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
+
+   if (!iw->fullscreen) return;
+
+   gtk_signal_emit (GTK_OBJECT(iw),
+                    gimv_image_win_signals[HIDE_FULLSCREEN_SIGNAL]);
+}
+
+
+static void
+gimv_image_win_real_show_fullscreen (GimvImageWin *iw)
 { 
    g_return_if_fail (iw);
 
@@ -2114,9 +2177,7 @@ gimv_image_win_fullscreen_show (GimvImageWin *iw)
                        iw);
 
    /* set draw widget */
-   if (!(iw->slideshow && conf.slideshow_set_bg)
-       && conf.imgwin_fullscreen_set_bg)
-   {
+   if (iw->priv->fs_bg_color) {
       GtkStyle *style;
       GdkColor *color = g_new0 (GdkColor, 1);
 
@@ -2130,17 +2191,21 @@ gimv_image_win_fullscreen_show (GimvImageWin *iw)
 
       /* set bg color */
       gimv_image_view_set_bg_color (iw->iv,
-                                    conf.imgwin_fullscreen_bg_color[0],
-                                    conf.imgwin_fullscreen_bg_color[1],
-                                    conf.imgwin_fullscreen_bg_color[2]);
+                                    iw->priv->fs_bg_color->red,
+                                    iw->priv->fs_bg_color->green,
+                                    iw->priv->fs_bg_color->blue);
    }
 
    gtk_widget_show (iw->fullscreen);
 
+#if (GTK_MAJOR_VERION >= 2) && (GTK_MINOR_VERSION >= 2)
+   gdk_window_fullscreen (iw->fullscreen->window);
+#else /* (GTK_MAJOR_VERION >= 2) && (GTK_MINOR_VERSION >= 2) */
    gtk_widget_set_uposition (iw->fullscreen, 0, 0);
    gtk_window_set_default_size (GTK_WINDOW (iw->fullscreen),
                                 gdk_screen_width (),
                                 gdk_screen_height ());
+#endif /* (GTK_MAJOR_VERION >= 2) && (GTK_MINOR_VERSION >= 2) */
 
    gimv_image_view_set_fullscreen (iw->iv, GTK_WINDOW (iw->fullscreen));
 
@@ -2159,7 +2224,7 @@ gimv_image_win_fullscreen_show (GimvImageWin *iw)
 
 
 static void
-gimv_image_win_fullscreen_hide (GimvImageWin *iw)
+gimv_image_win_real_hide_fullscreen (GimvImageWin *iw)
 {
    GdkColor *color;
 
@@ -2186,9 +2251,6 @@ gimv_image_win_fullscreen_hide (GimvImageWin *iw)
    gtk_widget_destroy (iw->fullscreen);
    iw->fullscreen = NULL;
    iw->priv->flags &= ~GimvImageWinFullScreenFlag;
-
-   if (iw->slideshow)
-      gtk_widget_destroy (GTK_WIDGET (iw));
 }
 
 
@@ -2228,7 +2290,7 @@ gimv_image_win_player_set_sensitive_all (GimvImageWin *iw, gboolean sensitive)
 
 
 void
-gimv_image_win_change_image (GimvImageWin *iw, ImageInfo *info)
+gimv_image_win_change_image (GimvImageWin *iw, GimvImageInfo *info)
 {
    GList *node;
    gboolean fit_to_frame;
@@ -2277,7 +2339,7 @@ gimv_image_win_save_state (GimvImageWin *iw)
 {
    g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
 
-   if (iw->slideshow) return;
+   if (iw->priv->flags & GimvImageWinNotSaveStateFlag) return;
 
    if (!(iw->priv->flags & GimvImageWinMaximizeFlag)) {
       conf.imgwin_width  = GTK_WIDGET(iw)->allocation.width;
@@ -2300,7 +2362,7 @@ gimv_image_win_save_state (GimvImageWin *iw)
 
 
 GimvImageWin *
-gimv_image_win_open_window (ImageInfo *info)
+gimv_image_win_open_window (GimvImageInfo *info)
 {
    GimvImageWin *iw;
 
@@ -2312,7 +2374,7 @@ gimv_image_win_open_window (ImageInfo *info)
 
 
 GimvImageWin *
-gimv_image_win_open_shared_window (ImageInfo *info)
+gimv_image_win_open_shared_window (GimvImageInfo *info)
 {
    GimvImageWin *iw;
 
@@ -2330,7 +2392,7 @@ gimv_image_win_open_shared_window (ImageInfo *info)
 
 
 GimvImageWin *
-gimv_image_win_open_window_auto (ImageInfo *info)
+gimv_image_win_open_window_auto (GimvImageInfo *info)
 {
    GimvImageWin *iw;
 
@@ -2470,3 +2532,35 @@ gimv_image_win_set_fullscreen (GimvImageWin *iw, gboolean show)
    g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
    menu_check_item_set_active (iw->view_menu, "/Full Screen", show);
 }
+
+
+void
+gimv_image_win_set_fullscreen_bg_color (GimvImageWin *iw,
+                                        gint red, gint green, gint blue)
+{
+   g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
+
+   if (!iw->priv->fs_bg_color)
+      iw->priv->fs_bg_color = g_new0 (GdkColor, 1);
+
+   iw->priv->fs_bg_color->red   = red;
+   iw->priv->fs_bg_color->green = green;
+   iw->priv->fs_bg_color->blue  = blue;
+}
+
+
+void
+gimv_image_win_set_flags (GimvImageWin  *iw, GimvImageWinFlags flags)
+{
+   g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
+   iw->priv->flags |= flags;
+}
+
+
+void
+gimv_image_win_unset_flags (GimvImageWin  *iw, GimvImageWinFlags flags)
+{
+   g_return_if_fail (GIMV_IS_IMAGE_WIN (iw));
+   iw->priv->flags &= ~flags;
+}
+
